@@ -28,4 +28,4 @@ class MolSmiles:
 
 
 if __name__ == "__main__":
-    print(MolSmiles.remove_map_num('N=[c:1][c:2]'))
+    print(MolSmiles.get_smiles_without_map_num(AllChem.MolFromSmiles('N=[CH:1][CH3:2]')))
