@@ -5,6 +5,9 @@
 # @File    : __init__.py.py
 # @Software: PyCharm
 
+from chem_scripts.rxn_handler.rxn_cleaner import RxnCleaner
+from chem_scripts.rxn_handler.rxn_smiles import RxnSmiles
+
 
 if __name__ == "__main__":
     pass
